/*                                                                                                            
 * Copyright (c) 2001 EU DataGrid.                                                                             
 * For license conditions see http://www.eu-datagrid.org/license.html                                          
 *
 * Copyright (c) 2001, 2002 by 
 *     Martijn Steenbakkers <martijn@nikhef.nl>,
 *     David Groep <davidg@nikhef.nl>,
 *     NIKHEF Amsterdam, the Netherlands
 */

/*!
    \file   lcas.h
    \brief  API of the LCAS library
    \author Martijn Steenbakkers for the EU DataGrid.

    This header contains the declarations of the LCAS library functions:
    -# lcas_init(): To initialize the LCAS module
    -# lcas_get_fabric_authorization(): to place an authorization request
    -# lcas_term(): To cleanly terminate the module
    \ingroup LcasInterface
*/
/*!
    \defgroup LcasInterface Interface to LCAS (library)
    \brief The API is available by including the header lcas.h
*/

#ifndef LCAS_H
#define LCAS_H

/******************************************************************************
                             Include header files
******************************************************************************/
#include <gssapi.h>
#include "lcas_types.h"

/******************************************************************************
 *                 Module definition
 *****************************************************************************/

/******************************************************************************
Function:   lcas_init
Description:
    Initialize LCAS module: 
    setup logging, error handling
    read from LCAS database the plugins to be loaded

Parameters:
    fp: file handle for logging (from gatekeeper)
Returns:
    0: initialization succeeded
    1: initialization failed
******************************************************************************/
/*!
    \fn lcas_init(
        FILE* fp
        )
    \brief Initialize the LCAS module.

    The function does the following:
    - initialize LCAS module.
    - setup logging, error handling (not yet).
    - read from LCAS database the plugins to be loaded.
    - initialize the plugins

    \param fp file handle for logging (from gatekeeper)
    \retval 0 initialization succeeded.
    \retval 1 initialization failed.
*/
extern int lcas_init(
        FILE* fp
);

/******************************************************************************
Function:   lcas_term
Description:
    Terminate LCAS module: 

Parameters:
Returns:
    0: termination succeeded
    1: termination failed
******************************************************************************/
/*!
    \fn lcas_term()
    \brief Terminate the LCAS module.

    The function does the following:
    - terminate the LCAS module
    - terminate the plugins

    \retval 0 initialization succeeded.
    \retval 1 initialization failed.
*/
extern int lcas_term();

/******************************************************************************
Function:   lcas_get_fabric_authorization
Description:
    Call LCAS in order to get authorization on the local fabric

Parameters:
    request: JDL
    user_cred : user globus credential handle
Returns:
    0: authorization succeeded
    1: authorization failed
******************************************************************************/
/*!
    \fn lcas_get_fabric_authorization(
        gss_cred_id_t user_cred,
        lcas_request_t request
    )
    \brief submit authorization request to the LCAS

    This function calls the plugins for authorization.

    \param request   authorization request in RSL (later JDL)
    \param user_cred GLOBUS user credential

    \retval 0 initialization succeeded.
    \retval 1 initialization failed.
*/
#if ALLOW_EMPTY_CREDENTIALS
extern int lcas_get_fabric_authorization(
        char * user_dn_tmp,
        gss_cred_id_t user_cred,
        lcas_request_t request
);
#else
extern int lcas_get_fabric_authorization(
        gss_cred_id_t user_cred,
        lcas_request_t request
);
#endif

extern int getMajorVersionNumber();
extern int getMinorVersionNumber();
extern int getPatchVersionNumber();

#endif /* LCAS_H */

/******************************************************************************
CVS Information:
    $Source: /local/reps/lcgware/fabric_mgt/gridification/lcas/include/lcas.h,v $
    $Date: 2003/05/28 14:36:31 $
    $Revision: 2.6 $
    $Author: martijn $
******************************************************************************/
