/*                                                                                                            
 * Copyright (c) 2001 EU DataGrid.                                                                             
 * For license conditions see http://www.eu-datagrid.org/license.html                                          
 *
 * Copyright (c) 2001, 2002 by 
 *     Martijn Steenbakkers <martijn@nikhef.nl>,
 *     David Groep <davidg@nikhef.nl>,
 *     NIKHEF Amsterdam, the Netherlands
 */

/*!
    \file   lcas_utils.h
    \brief  API for the utilities for the LCAS
    \author Martijn Steenbakkers for the EU DataGrid.

    This header contains the declarations of the LCAS utility functions:
    -# lcas_get_dn():
    -# lcas_genfilename(): 
    -# lcas_getfexist():
    -# lcas_findfile():
    \ingroup APIforLcasPlugins
*/

#ifndef LCAS_UTILS_H
#define LCAS_UTILS_H

/******************************************************************************
                             Include header files
******************************************************************************/
#include <gssapi.h>
#include "lcas_types.h"

/******************************************************************************
 *                 Module definition
 *****************************************************************************/

/*! \name CREDENTIAL FUNCTIONS */
/*@{*/ /* Beginning of credential functions */

/******************************************************************************
Function:       lcas_get_dn()
Description:    returns user dn
Parameters:
                lcas_cred: lcas_credential
Returns:        user dn
******************************************************************************/
/*!
    \fn lcas_get_dn(
        lcas_cred_id_t lcas_credential
        )
    \brief Retrieve user DN from (LCAS) credential

    This function takes an LCAS credential as input and returns the corresponding
    user distinguished name (DN).
    
    (Internal:) If the GLOBUS credential part of the LCAS credential is empty
    the user DN is already included in the LCAS credential.

    \param lcas_credential the LCAS credential
    \return a string containing the user DN
*/
extern char * lcas_get_dn(
        lcas_cred_id_t lcas_credential
);


/******************************************************************************
Function:       lcas_get_gss_cred()
Description:    returns globus gss credential
Parameters:
                lcas_cred: lcas_credential
Returns:        globus gss credential
******************************************************************************/
/*!
    \fn lcas_get_gss_cred(
        lcas_cred_id_t lcas_credential
        )
    \brief Retrieve globus gss credential from (LCAS) credential

    This function takes an LCAS credential as input and returns the corresponding
    globus gss credential.
    
    \param lcas_credential the LCAS credential
    \return globus gss credential
*/
extern gss_cred_id_t lcas_get_gss_cred(
        lcas_cred_id_t lcas_credential
);

/*@}*/ /* End of credential functions */

/*! \name FILENAME FUNCTIONS */
/*@{*/ /* Beginning of filename functions */
/******************************************************************************
Function:       lcas_genfilename() (copied from GLOBUS gatekeeper.c)
Description:    generate an absolute file name given a starting prefix,
                a relative or absolute path, and a suffix
                Only use prefix if path is relative.
Parameters:
Returns:        a pointer to a string which could be freeded.
******************************************************************************/
/*!
    \fn lcas_genfilename(
        char * prefix,
        char * path,
        char * suffix
        )
    \brief Generate an absolute file name.
    
    Given a starting prefix, a relative or absolute path, and a suffix an
    absolute file name is generated. Uses the prefix only if
    the path is relative. (Copied (and modified) from GLOBUS gatekeeper.c)
    
    \param prefix string containing the prefix to be prepended.
    \param path   relative/absolute path to file name.
    \param suffix string containing the suffix to be appended.

    \return pointer to a string containing the absolute path to the file, which has to
    be freed.
*/
extern char * lcas_genfilename(
        char * prefix,
        char * path,
        char * suffix
);

/******************************************************************************
Function:       lcas_getfexist()
Description:    picks the first existing file in argument list
Parameters:     n   : number of paths,
                ... : list of paths
Returns:        returns filename found or NULL
******************************************************************************/
/*!
    \fn lcas_getfexist(
        int n,
        ...
        )
    \brief Picks the first existing file in argument list.

    \param n   the number of paths presented in the following argument list.
    \param ... variable argument list of paths.

    \return filename found or NULL
*/
extern char * lcas_getfexist(
        int n,
        ...
);

/******************************************************************************
Function:       lcas_findfile()
Description:    Checks for file in standard directories
Parameters:     name
Returns:        returns filename found (should be freeed) or NULL
******************************************************************************/
/*!
    \fn lcas_findfile(
        char * name
        )
    \brief Checks for file in standard directories

    The directories that are checked are:
    - current directory
    - "modules"
    - LCAS_ETC_HOME
    - LCAS_MOD_HOME
    - LCAS_LIB_HOME

    \param name string containing the file name
    \return pointer to a string containing the absolute path to the file, which has to
    be freed or NULL.
*/
extern char * lcas_findfile(
        char * name
);
/*@}*/ /* End of filename functions */

#endif /* LCAS_UTILS_H */

/******************************************************************************
CVS Information:
    $Source: /local/reps/lcgware/fabric_mgt/gridification/lcas/include/lcas_utils.h,v $
    $Date: 2003/08/08 16:16:07 $
    $Revision: 2.8 $
    $Author: martijn $
******************************************************************************/
